@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -13,7 +13,8 @@ use Class::Sniff;
 
 
 has class => (
-    is => 'ro',
+    is       => 'ro',
+    required => 1,
 );
 
 
@@ -98,7 +99,7 @@ Test::NaiveStubs - Generate test stubs for methods
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -123,7 +124,7 @@ The class name to use in the test generation.
 
 =head2 name
 
-The test output file name.
+The test output file name. Default: t/test.t
 
 =head1 METHODS
 
